---
title: Memory Tools API Reference
---

# Memory Tools API Reference

::: langmem
    handler: python
    options:
      members:
        - create_manage_memory_tool
        - create_search_memory_tool
